searchData={"content_type":"text/markdown","items":[{"doc":"Contains the main functions to initialize and render the tags.","ref":"Liquor.html","title":"Liquor","type":"module"},{"doc":"Initializes the Liquor map with content, tags and fetch function.","ref":"Liquor.html#init/3","title":"Liquor.init/3","type":"function"},{"doc":"Initializes, finds and render the tags","ref":"Liquor.html#render/3","title":"Liquor.render/3","type":"function"},{"doc":"Initialized the map with the content, tags and fetch. Fetch must call the URL and return the HTML string to extract the OpenGraph data.","ref":"Liquor.html#t:t/0","title":"Liquor.t/0","type":"type"},{"doc":"Tags finds the \"Liquor Tags\" inside a plain text document.\nEg: `{% embed https://ninjas.cl %}` then fetches the open graph\ndata from the url and renders using a pseudo EEx template.","ref":"Liquor.Tags.html","title":"Liquor.Tags","type":"module"},{"doc":"Finds the tags inside a document.\nAnd generate an output with the open graph data for each match.","ref":"Liquor.Tags.html#find/1","title":"Liquor.Tags.find/1","type":"function"},{"doc":"iex> Liquor.init(\"{% embed https://ninjas.cl %}\", [Liquor.Tags.Tag.new(\"embed\", \"<%= og.url %>\")], fn url -> Req.get!(url) |> then(& &1.body) end) |> Liquor.Tags.find() |> then(& List.first(&1.tags)) |> then(& List.first(&1.matches).output)\n    \"https://ninjas.cl\"","ref":"Liquor.Tags.html#find/1-examples","title":"Examples - Liquor.Tags.find/1","type":"function"},{"doc":"Given a list of tags with open graph data.\nReplace each tag with the rendered output from the tag.","ref":"Liquor.Tags.html#render/1","title":"Liquor.Tags.render/1","type":"function"},{"doc":"iex> Liquor.init(\"{% embed https://ninjas.cl %}\", [Liquor.Tags.Tag.new(\"embed\", \"<%= og.url %>\")], fn url -> Req.get!(url) |> then(& &1.body) end) |> Liquor.Tags.find() |> Liquor.Tags.render()\n    \"https://ninjas.cl\"","ref":"Liquor.Tags.html#render/1-examples","title":"Examples - Liquor.Tags.render/1","type":"function"},{"doc":"","ref":"Liquor.Tags.html#t:t/0","title":"Liquor.Tags.t/0","type":"type"},{"doc":"The Tag module holds the structure for a Tag.\nA Tag consist of a identification string (tag)\na URI for OpenGraph (base_url) and a pseudo\nEEx template string.","ref":"Liquor.Tags.Tag.html","title":"Liquor.Tags.Tag","type":"module"},{"doc":"Helps creating a new Tag.\nThe template is a string with pseudo EEx (for safer evaluation).\nThe URI is a string that can be used as a base URL\nfor all the tags when fetching the Open Graph data.","ref":"Liquor.Tags.Tag.html#new/3","title":"Liquor.Tags.Tag.new/3","type":"function"},{"doc":"iex> Liquor.Tags.Tag.new(\"embed\", \"<%= og.title %>\")\n    %Liquor.Tags.Tag{tag: \"embed\", template: \"<%= og.title %>\", uri: %URI{}}","ref":"Liquor.Tags.Tag.html#new/3-examples","title":"Examples - Liquor.Tags.Tag.new/3","type":"function"},{"doc":"A safer way to replace the tags\nInstead of EEx.eval_string()\nThis function is recommended to use cases\nwhen the user can send input.\n\nThe template string can use a pseudo EEx tags.\nExample `<%= og.title %>` for rendering the\nopen graph data.\n\nCheck https://github.com/bitboxer/opengraph_parser/blob/main/lib/open_graph.ex#L55\nfor all the available keys.","ref":"Liquor.Tags.Tag.html#render/2","title":"Liquor.Tags.Tag.render/2","type":"function"},{"doc":"iex> Liquor.Tags.Tag.render(Liquor.Tags.Tag.new(\"embed\", \"<%= og.title %>\"), [og: %OpenGraph{title: \"A Sample Title\"}])\n    \"A Sample Title\"","ref":"Liquor.Tags.Tag.html#render/2-examples","title":"Examples - Liquor.Tags.Tag.render/2","type":"function"},{"doc":"A Tag consists of a string identification (tag), an URI and an pseudo EEx template string","ref":"Liquor.Tags.Tag.html#t:t/0","title":"Liquor.Tags.Tag.t/0","type":"type"},{"doc":"# [Liquor](https://github.com/elixircl/liquor)\n\nLiquor Tags. Inspired by dev.to embed tags (liquid), takes Open Graph data from URLs and generate output using pseudo EEx templates.","ref":"readme.html","title":"Liquor","type":"extras"},{"doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `liquor` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:liquor, \"~> 1.0.0\"}\n  ]\nend\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#installation","title":"Installation - Liquor","type":"extras"},{"doc":"Mozilla Public License Version 2.0\r\n==================================\r\n\r\n#","ref":"license.html","title":"Mozilla Public License Version 2.0","type":"extras"},{"doc":"**1.1. “Contributor”**\r\nmeans each individual or legal entity that creates, contributes to\r\nthe creation of, or owns Covered Software.\r\n\r\n**1.2. “Contributor Version”**\r\nmeans the combination of the Contributions of others (if any) used\r\nby a Contributor and that particular Contributor's Contribution.\r\n\r\n**1.3. “Contribution”**\r\nmeans Covered Software of a particular Contributor.\r\n\r\n**1.4. “Covered Software”**\r\nmeans Source Code Form to which the initial Contributor has attached\r\nthe notice in Exhibit A, the Executable Form of such Source Code\r\nForm, and Modifications of such Source Code Form, in each case\r\nincluding portions thereof.\r\n\r\n**1.5. “Incompatible With Secondary Licenses”**\r\nmeans\r\n\r\n* **(a)** that the initial Contributor has attached the notice described\r\n  in Exhibit B to the Covered Software; or\r\n* **(b)** that the Covered Software was made available under the terms of\r\n  version 1.1 or earlier of the License, but not also under the\r\n  terms of a Secondary License.\r\n\r\n**1.6. “Executable Form”**\r\nmeans any form of the work other than Source Code Form.\r\n\r\n**1.7. “Larger Work”**\r\nmeans a work that combines Covered Software with other material, in\r\na separate file or files, that is not Covered Software.\r\n\r\n**1.8. “License”**\r\nmeans this document.\r\n\r\n**1.9. “Licensable”**\r\nmeans having the right to grant, to the maximum extent possible,\r\nwhether at the time of the initial grant or subsequently, any and\r\nall of the rights conveyed by this License.\r\n\r\n**1.10. “Modifications”**\r\nmeans any of the following:\r\n\r\n* **(a)** any file in Source Code Form that results from an addition to,\r\n  deletion from, or modification of the contents of Covered\r\n  Software; or\r\n* **(b)** any new file in Source Code Form that contains any Covered\r\n  Software.\r\n\r\n**1.11. “Patent Claims” of a Contributor**\r\nmeans any patent claim(s), including without limitation, method,\r\nprocess, and apparatus claims, in any patent Licensable by such\r\nContributor that would be infringed, but for the grant of the\r\nLicense, by the making, using, selling, offering for sale, having\r\nmade, import, or transfer of either its Contributions or its\r\nContributor Version.\r\n\r\n**1.12. “Secondary License”**\r\nmeans either the GNU General Public License, Version 2.0, the GNU\r\nLesser General Public License, Version 2.1, the GNU Affero General\r\nPublic License, Version 3.0, or any later versions of those\r\nlicenses.\r\n\r\n**1.13. “Source Code Form”**\r\nmeans the form of the work preferred for making modifications.\r\n\r\n**1.14. “You” (or “Your”)**\r\nmeans an individual or a legal entity exercising rights under this\r\nLicense. For legal entities, “You” includes any entity that\r\ncontrols, is controlled by, or is under common control with You. For\r\npurposes of this definition, “control” means **(a)** the power, direct\r\nor indirect, to cause the direction or management of such entity,\r\nwhether by contract or otherwise, or **(b)** ownership of more than\r\nfifty percent (50%) of the outstanding shares or beneficial\r\nownership of such entity.\r\n\r\n\r\n#","ref":"license.html#1-definitions","title":"1. Definitions - Mozilla Public License Version 2.0","type":"extras"},{"doc":"##","ref":"license.html#2-license-grants-and-conditions","title":"2. License Grants and Conditions - Mozilla Public License Version 2.0","type":"extras"},{"doc":"Each Contributor hereby grants You a world-wide, royalty-free,\r\nnon-exclusive license:\r\n\r\n* **(a)** under intellectual property rights (other than patent or trademark)\r\n  Licensable by such Contributor to use, reproduce, make available,\r\n  modify, display, perform, distribute, and otherwise exploit its\r\n  Contributions, either on an unmodified basis, with Modifications, or\r\n  as part of a Larger Work; and\r\n* **(b)** under Patent Claims of such Contributor to make, use, sell, offer\r\n  for sale, have made, import, and otherwise transfer either its\r\n  Contributions or its Contributor Version.\r\n\r\n##","ref":"license.html#2-1-grants","title":"2.1. Grants - Mozilla Public License Version 2.0","type":"extras"},{"doc":"The licenses granted in Section 2.1 with respect to any Contribution\r\nbecome effective for each Contribution on the date the Contributor first\r\ndistributes such Contribution.\r\n\r\n##","ref":"license.html#2-2-effective-date","title":"2.2. Effective Date - Mozilla Public License Version 2.0","type":"extras"},{"doc":"The licenses granted in this Section 2 are the only rights granted under\r\nthis License. No additional rights or licenses will be implied from the\r\ndistribution or licensing of Covered Software under this License.\r\nNotwithstanding Section 2.1(b) above, no patent license is granted by a\r\nContributor:\r\n\r\n* **(a)** for any code that a Contributor has removed from Covered Software;\r\n  or\r\n* **(b)** for infringements caused by: **(i)** Your and any other third party's\r\n  modifications of Covered Software, or **(ii)** the combination of its\r\n  Contributions with other software (except as part of its Contributor\r\n  Version); or\r\n* **(c)** under Patent Claims infringed by Covered Software in the absence of\r\n  its Contributions.\r\n\r\nThis License does not grant any rights in the trademarks, service marks,\r\nor logos of any Contributor (except as may be necessary to comply with\r\nthe notice requirements in Section 3.4).\r\n\r\n##","ref":"license.html#2-3-limitations-on-grant-scope","title":"2.3. Limitations on Grant Scope - Mozilla Public License Version 2.0","type":"extras"},{"doc":"No Contributor makes additional grants as a result of Your choice to\r\ndistribute the Covered Software under a subsequent version of this\r\nLicense (see Section 10.2) or under the terms of a Secondary License (if\r\npermitted under the terms of Section 3.3).\r\n\r\n##","ref":"license.html#2-4-subsequent-licenses","title":"2.4. Subsequent Licenses - Mozilla Public License Version 2.0","type":"extras"},{"doc":"Each Contributor represents that the Contributor believes its\r\nContributions are its original creation(s) or it has sufficient rights\r\nto grant the rights to its Contributions conveyed by this License.\r\n\r\n##","ref":"license.html#2-5-representation","title":"2.5. Representation - Mozilla Public License Version 2.0","type":"extras"},{"doc":"This License is not intended to limit any rights You have under\r\napplicable copyright doctrines of fair use, fair dealing, or other\r\nequivalents.\r\n\r\n##","ref":"license.html#2-6-fair-use","title":"2.6. Fair Use - Mozilla Public License Version 2.0","type":"extras"},{"doc":"Sections 3.1, 3.2, 3.3, and 3.4 are conditions of the licenses granted\r\nin Section 2.1.\r\n\r\n\r\n#","ref":"license.html#2-7-conditions","title":"2.7. Conditions - Mozilla Public License Version 2.0","type":"extras"},{"doc":"##","ref":"license.html#3-responsibilities","title":"3. Responsibilities - Mozilla Public License Version 2.0","type":"extras"},{"doc":"All distribution of Covered Software in Source Code Form, including any\r\nModifications that You create or to which You contribute, must be under\r\nthe terms of this License. You must inform recipients that the Source\r\nCode Form of the Covered Software is governed by the terms of this\r\nLicense, and how they can obtain a copy of this License. You may not\r\nattempt to alter or restrict the recipients' rights in the Source Code\r\nForm.\r\n\r\n##","ref":"license.html#3-1-distribution-of-source-form","title":"3.1. Distribution of Source Form - Mozilla Public License Version 2.0","type":"extras"},{"doc":"If You distribute Covered Software in Executable Form then:\r\n\r\n* **(a)** such Covered Software must also be made available in Source Code\r\n  Form, as described in Section 3.1, and You must inform recipients of\r\n  the Executable Form how they can obtain a copy of such Source Code\r\n  Form by reasonable means in a timely manner, at a charge no more\r\n  than the cost of distribution to the recipient; and\r\n\r\n* **(b)** You may distribute such Executable Form under the terms of this\r\n  License, or sublicense it under different terms, provided that the\r\n  license for the Executable Form does not attempt to limit or alter\r\n  the recipients' rights in the Source Code Form under this License.\r\n\r\n##","ref":"license.html#3-2-distribution-of-executable-form","title":"3.2. Distribution of Executable Form - Mozilla Public License Version 2.0","type":"extras"},{"doc":"You may create and distribute a Larger Work under terms of Your choice,\r\nprovided that You also comply with the requirements of this License for\r\nthe Covered Software. If the Larger Work is a combination of Covered\r\nSoftware with a work governed by one or more Secondary Licenses, and the\r\nCovered Software is not Incompatible With Secondary Licenses, this\r\nLicense permits You to additionally distribute such Covered Software\r\nunder the terms of such Secondary License(s), so that the recipient of\r\nthe Larger Work may, at their option, further distribute the Covered\r\nSoftware under the terms of either this License or such Secondary\r\nLicense(s).\r\n\r\n##","ref":"license.html#3-3-distribution-of-a-larger-work","title":"3.3. Distribution of a Larger Work - Mozilla Public License Version 2.0","type":"extras"},{"doc":"You may not remove or alter the substance of any license notices\r\n(including copyright notices, patent notices, disclaimers of warranty,\r\nor limitations of liability) contained within the Source Code Form of\r\nthe Covered Software, except that You may alter any license notices to\r\nthe extent required to remedy known factual inaccuracies.\r\n\r\n##","ref":"license.html#3-4-notices","title":"3.4. Notices - Mozilla Public License Version 2.0","type":"extras"},{"doc":"You may choose to offer, and to charge a fee for, warranty, support,\r\nindemnity or liability obligations to one or more recipients of Covered\r\nSoftware. However, You may do so only on Your own behalf, and not on\r\nbehalf of any Contributor. You must make it absolutely clear that any\r\nsuch warranty, support, indemnity, or liability obligation is offered by\r\nYou alone, and You hereby agree to indemnify every Contributor for any\r\nliability incurred by such Contributor as a result of warranty, support,\r\nindemnity or liability terms You offer. You may include additional\r\ndisclaimers of warranty and limitations of liability specific to any\r\njurisdiction.\r\n\r\n\r\n#","ref":"license.html#3-5-application-of-additional-terms","title":"3.5. Application of Additional Terms - Mozilla Public License Version 2.0","type":"extras"},{"doc":"If it is impossible for You to comply with any of the terms of this\r\nLicense with respect to some or all of the Covered Software due to\r\nstatute, judicial order, or regulation then You must: **(a)** comply with\r\nthe terms of this License to the maximum extent possible; and **(b)**\r\ndescribe the limitations and the code they affect. Such description must\r\nbe placed in a text file included with all distributions of the Covered\r\nSoftware under this License. Except to the extent prohibited by statute\r\nor regulation, such description must be sufficiently detailed for a\r\nrecipient of ordinary skill to be able to understand it.\r\n\r\n\r\n#","ref":"license.html#4-inability-to-comply-due-to-statute-or-regulation","title":"4. Inability to Comply Due to Statute or Regulation - Mozilla Public License Version 2.0","type":"extras"},{"doc":"**5.1.** The rights granted under this License will terminate automatically\r\nif You fail to comply with any of its terms. However, if You become\r\ncompliant, then the rights granted under this License from a particular\r\nContributor are reinstated **(a)** provisionally, unless and until such\r\nContributor explicitly and finally terminates Your grants, and **(b)** on an\r\nongoing basis, if such Contributor fails to notify You of the\r\nnon-compliance by some reasonable means prior to 60 days after You have\r\ncome back into compliance. Moreover, Your grants from a particular\r\nContributor are reinstated on an ongoing basis if such Contributor\r\nnotifies You of the non-compliance by some reasonable means, this is the\r\nfirst time You have received notice of non-compliance with this License\r\nfrom such Contributor, and You become compliant prior to 30 days after\r\nYour receipt of the notice.\r\n\r\n**5.2.** If You initiate litigation against any entity by asserting a patent\r\ninfringement claim (excluding declaratory judgment actions,\r\ncounter-claims, and cross-claims) alleging that a Contributor Version\r\ndirectly or indirectly infringes any patent, then the rights granted to\r\nYou by any and all Contributors for the Covered Software under Section\r\n2.1 of this License shall terminate.\r\n\r\n**5.3.** In the event of termination under Sections 5.1 or 5.2 above, all\r\nend user license agreements (excluding distributors and resellers) which\r\nhave been validly granted by You or Your distributors under this License\r\nprior to termination shall survive termination.\r\n\r\n\r\n#","ref":"license.html#5-termination","title":"5. Termination - Mozilla Public License Version 2.0","type":"extras"},{"doc":"> Covered Software is provided under this License on an “as is”\r\n> basis, without warranty of any kind, either expressed, implied, or\r\n> statutory, including, without limitation, warranties that the\r\n> Covered Software is free of defects, merchantable, fit for a\r\n> particular purpose or non-infringing. The entire risk as to the\r\n> quality and performance of the Covered Software is with You.\r\n> Should any Covered Software prove defective in any respect, You\r\n> (not any Contributor) assume the cost of any necessary servicing,\r\n> repair, or correction. This disclaimer of warranty constitutes an\r\n> essential part of this License. No use of any Covered Software is\r\n> authorized under this License except under this disclaimer.\r\n\r\n#","ref":"license.html#6-disclaimer-of-warranty","title":"6. Disclaimer of Warranty - Mozilla Public License Version 2.0","type":"extras"},{"doc":"> Under no circumstances and under no legal theory, whether tort\r\n> (including negligence), contract, or otherwise, shall any\r\n> Contributor, or anyone who distributes Covered Software as\r\n> permitted above, be liable to You for any direct, indirect,\r\n> special, incidental, or consequential damages of any character\r\n> including, without limitation, damages for lost profits, loss of\r\n> goodwill, work stoppage, computer failure or malfunction, or any\r\n> and all other commercial damages or losses, even if such party\r\n> shall have been informed of the possibility of such damages. This\r\n> limitation of liability shall not apply to liability for death or\r\n> personal injury resulting from such party's negligence to the\r\n> extent applicable law prohibits such limitation. Some\r\n> jurisdictions do not allow the exclusion or limitation of\r\n> incidental or consequential damages, so this exclusion and\r\n> limitation may not apply to You.\r\n\r\n\r\n#","ref":"license.html#7-limitation-of-liability","title":"7. Limitation of Liability - Mozilla Public License Version 2.0","type":"extras"},{"doc":"Any litigation relating to this License may be brought only in the\r\ncourts of a jurisdiction where the defendant maintains its principal\r\nplace of business and such litigation shall be governed by laws of that\r\njurisdiction, without reference to its conflict-of-law provisions.\r\nNothing in this Section shall prevent a party's ability to bring\r\ncross-claims or counter-claims.\r\n\r\n\r\n#","ref":"license.html#8-litigation","title":"8. Litigation - Mozilla Public License Version 2.0","type":"extras"},{"doc":"This License represents the complete agreement concerning the subject\r\nmatter hereof. If any provision of this License is held to be\r\nunenforceable, such provision shall be reformed only to the extent\r\nnecessary to make it enforceable. Any law or regulation which provides\r\nthat the language of a contract shall be construed against the drafter\r\nshall not be used to construe this License against a Contributor.\r\n\r\n\r\n#","ref":"license.html#9-miscellaneous","title":"9. Miscellaneous - Mozilla Public License Version 2.0","type":"extras"},{"doc":"##","ref":"license.html#10-versions-of-the-license","title":"10. Versions of the License - Mozilla Public License Version 2.0","type":"extras"},{"doc":"Mozilla Foundation is the license steward. Except as provided in Section\r\n10.3, no one other than the license steward has the right to modify or\r\npublish new versions of this License. Each version will be given a\r\ndistinguishing version number.\r\n\r\n##","ref":"license.html#10-1-new-versions","title":"10.1. New Versions - Mozilla Public License Version 2.0","type":"extras"},{"doc":"You may distribute the Covered Software under the terms of the version\r\nof the License under which You originally received the Covered Software,\r\nor under the terms of any subsequent version published by the license\r\nsteward.\r\n\r\n##","ref":"license.html#10-2-effect-of-new-versions","title":"10.2. Effect of New Versions - Mozilla Public License Version 2.0","type":"extras"},{"doc":"If you create software not governed by this License, and you want to\r\ncreate a new license for such software, you may create and use a\r\nmodified version of this License if you rename the license and remove\r\nany references to the name of the license steward (except to note that\r\nsuch modified license differs from this License).\r\n\r\n##","ref":"license.html#10-3-modified-versions","title":"10.3. Modified Versions - Mozilla Public License Version 2.0","type":"extras"},{"doc":"If You choose to distribute Source Code Form that is Incompatible With\r\nSecondary Licenses under the terms of this version of the License, the\r\nnotice described in Exhibit B of this License must be attached.","ref":"license.html#10-4-distributing-source-code-form-that-is-incompatible-with-secondary-licenses","title":"10.4. Distributing Source Code Form that is Incompatible With Secondary Licenses - Mozilla Public License Version 2.0","type":"extras"},{"doc":"This Source Code Form is subject to the terms of the Mozilla Public\r\n    License, v. 2.0. If a copy of the MPL was not distributed with this\r\n    file, You can obtain one at http://mozilla.org/MPL/2.0/.\r\n\r\nIf it is not possible or desirable to put the notice in a particular\r\nfile, then You may include the notice in a location (such as a LICENSE\r\nfile in a relevant directory) where a recipient would be likely to look\r\nfor such a notice.\r\n\r\nYou may add additional accurate notices of copyright ownership.","ref":"license.html#exhibit-a-source-code-form-license-notice","title":"Exhibit A - Source Code Form License Notice - Mozilla Public License Version 2.0","type":"extras"},{"doc":"This Source Code Form is \"Incompatible With Secondary Licenses\", as\r\n    defined by the Mozilla Public License, v. 2.0.","ref":"license.html#exhibit-b-incompatible-with-secondary-licenses-notice","title":"Exhibit B - “Incompatible With Secondary Licenses” Notice - Mozilla Public License Version 2.0","type":"extras"},{"doc":"# Changelog\r\nAll notable changes to this project will be documented in this file.\r\n\r\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\r\nand this project adheres to [Romantic Versioning](http://sentimentalversioning.org/).\r\n\r\n## [1.0.0](https://github.com/elixircl/liquor/releases/tag/v1.0.0) - 2024-03-25\r\n#","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"- Can extract liquor tags from plain text and render them.","ref":"changelog.html#features","title":"Features - Changelog","type":"extras"},{"doc":"# Liquor Examples\n\n*Liquor Tags*. Inspired by dev.to embed tags (liquid tags),\ntakes Open Graph data from URLs and generate output using pseudo EEx templates.\nUseful when creating previews of websites using Open Graph data.","ref":"examples.html","title":"Liquor Examples","type":"extras"},{"doc":"```elixir\nMix.install([\n  {:liquor, git: \"https://github.com/ElixirCL/liquor.git\", branch: \"main\"},\n  {:req, \"~> 0.4.14\"},\n  {:kino, \"~> 0.12.3\"}\n])\n```\n\n```elixir\nalias Liquor.Tags.Tag\n\ncontent = \"\"\"\n{% github ElixirCL %}\n{% embed https://ninjas.cl %}\n\"\"\"\n\ntags = [\n  Tag.new(\"github\", \"Github: <%= og.url %>\", \"https://github.com\"),\n  Tag.new(\"embed\", \"Website: <%= og.title %>\")\n]\n\n# Fetch only needs to return the HTML string\nfetch = fn url -> Req.get!(url) |> then(& &1.body) end\n\nLiquor.render(content, tags, fetch)\n|> Kino.Text.new()\n```\n\n#","ref":"examples.html#installation","title":"Installation - Liquor Examples","type":"extras"},{"doc":"```text\nGithub: https://github.com/ElixirCL\nWebsite: Ninja Software Chile (Ninjas.cl)\n```\n\n#","ref":"examples.html#renders","title":"Renders - Liquor Examples","type":"extras"},{"doc":"You can also create a fetch function that caches\nthe html files like this:\n\n```elixir\nfetch =\n  fn url ->\n        md5 =\n          :crypto.hash(:md5, url)\n          |> Base.encode16(case: :lower)\n\n        path = Path.join([\".opengraph\"])\n        File.mkdir_p!(path)\n        file = Path.join([path, \"#{md5}.html.cache\"])\n\n        case File.read(file) do\n          {:error, _} ->\n                html = Req.get!(url)\n                |> then(& &1.body)\n\n                File.write!(file, html, [:write])\n                html\n\n          {:ok, html} -> html\n        end\n  end\n```","ref":"examples.html#advanced-fetch","title":"Advanced Fetch - Liquor Examples","type":"extras"},{"doc":"# Liquor Authors\r\n\r\n_Liquor_ was originally written by _Camilo Castro_ and is currently developed and maintained by [Elixir Chile](https://elixircl.github.io/).\r\n\r\n_Liquor_ is a collective work with contributions from many people, including:\r\n\r\n- Camilo Castro (@clsource)\r\n- Elixir Chile Collaborators.\r\n\r\nThanks!","ref":"authors.html","title":"Liquor Authors","type":"extras"}],"producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}